# Nicked a bunch of this from Hy
# https://github.com/hylang/hy/blob/master/hy/cmdline.py
import argparse
import os
import sys

from core import barf, cfg


def dir_check(thisdir):
	if not os.path.exists(thisdir):
		os.makedirs(thisdir)


def cmdline_handler(argv):
	parser = argparse.ArgumentParser(
		prog="scrib"
	)
	# this will contain the script/program name and any arguments for it.
	parser.add_argument(
		'args',
		nargs=argparse.REMAINDER,
		help=argparse.SUPPRESS
	)

	options = parser.parse_args(argv[1:])

	# Load registered interfaces or set up defaults
	if len(options.args) < 2:
		usage()
	
	dir_check(os.path.expanduser('~') + '/.scrib/')
	with open(os.path.expanduser("~") + '/.scrib/last_loaded', 'w') as f:
		f.write(options.args[0])

	interfaces = cfg.set()
	interfaces.load('interfaces.cfg', {
		'help': None,
		'cli': 'ScribCLI',
		'irc': 'ScribIRC'
	}, suppress=True)

	# User did "scrib <name> <filename>"
	try:
		load(interfaces.__dict__[options.args[1]])
	except IndexError:
		usage()
	except IOError as x:
		barf.Barf(
			'ERR',
			"scrib: Can't open interface '%s': [Errno %d] %s\n" % (
				x.filename,
				x.errno,
				x.strerror
			)
		)
		sys.exit(x.errno)


# entry point for cmd line script "scrib"
def scrib_main():
	sys.exit(cmdline_handler(sys.argv))


def usage():
	# Filter out everything but registered interfaces
	"""
	for a in interfaces.__dict__.keys():
		if '_defaults' in a:
				ifacelist = interfaces.__dict__[a]
	"""
	barf.Barf('MSG', 'scrib bot. Usage:', False)
	barf.Barf('MSG', 'start.py [bot] [interface]', False)
	"""
	barf.Barf(
		'MSG',
		'Available interfaces: %s' %
		', '.join(ifacelist.keys()), False
	)
	"""
	sys.exit()


def load(interface):
	if interface is None:
		usage()
	barf.Barf('MSG', 'Loading interface: %s' % interface)
	d = os.path.dirname(sys.modules['scrib'].__file__)
	os.chmod(os.path.join(d, 'interfaces/' + interface + '.py'), 0744)
	os.system(os.path.join(d, 'interfaces/' + interface + '.py'))
	sys.exit()
